@@ -2,16 +2,11 @@
 # License, v. 2.0. If a copy of the MPL was not distributed with this file,
 # You can obtain one at http://mozilla.org/MPL/2.0/.
 
-
 import datetime
+import logging
 import re
 import time
-import traceback
 
-try:
-    import json
-except:
-    import simplejson as json
 from dateutil.parser import parse
 
 from mozillapulse import consumers
@@ -33,7 +28,7 @@ class PulseBuildMonitor(object):
                  durable=False, platforms=None, tests=None,
                  buildtypes=None, products=None, buildtags=None,
                  logger=None, talos=False, builds=False,
-                 unittests=False, locales=None):
+                 unittests=False, locales=None, pulse_cfg=None):
         self.label = label
         self.trees = trees
         self.platforms = platforms
@@ -47,6 +42,11 @@ class PulseBuildMonitor(object):
         self.buildtags = buildtags
         self.unittests = unittests
         self.locales = locales
+        self.pulse_cfg = pulse_cfg
+
+        if not self.logger:
+            self.logger = logging.getLogger('pulsebuildmonitor')
+            self.logger.addHandler(logging.NullHandler())
 
         assert(self.talos or self.builds or self.unittests)
 
@@ -68,7 +68,10 @@ class PulseBuildMonitor(object):
 
     def make_pulse_consumer(self):
         self.logger.info('Connecting to Mozilla Pulse as "%s"...', self.label)
-        self.pulse = consumers.NormalizedBuildConsumer(applabel=self.label)
+        self.pulse = consumers.NormalizedBuildConsumer(applabel=self.label,
+                                                       connect=False)
+        if self.pulse_cfg:
+            self.pulse.config = self.pulse_cfg
         self.pulse.configure(topic=self.topics,
                              callback=self.pulse_message_received,
                              durable=self.durable)
@@ -99,9 +102,7 @@ class PulseBuildMonitor(object):
                 self.make_pulse_consumer()
                 self.pulse.listen(on_connect_callback=self.on_connect_callback)
             except Exception, inst:
-                if self.logger:
-                    self.logger.exception(inst)
-                    traceback.print_exc()
+                self.logger.exception(inst)
             now = datetime.datetime.now()
             failures = [x for x in failures
                         if now - x < datetime.timedelta(seconds=60)]
@@ -216,6 +217,5 @@ class PulseBuildMonitor(object):
         except Exception, inst:
             if self.logger:
                 self.logger.exception(inst)
-                traceback.print_exc()
             else:
                 raise
